@@ -8,7 +8,7 @@
  * See the file "COPYING" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * $Id: tclrrd.c 956 2007-01-20 20:03:14Z oetiker $
+ * $Id: tclrrd.c 1044 2007-05-02 05:08:21Z oetiker $
  */
 
 
@@ -18,8 +18,8 @@
 #include <time.h>
 #include <unistd.h>
 #include <tcl.h>
-#include <rrd_tool.h>
-#include <rrd_format.h>
+#include "../../src/rrd_tool.h"
+#include "../../src/rrd_format.h"
 
 /* support pre-8.4 tcl */
 
