@@ -1,14 +1,16 @@
 /****************************************************************************
- * RRDtool 1.2.15  Copyright by Tobi Oetiker, 1997-2006
+ * RRDtool 1.2.23  Copyright by Tobi Oetiker, 1997-2007
  ****************************************************************************
  * rrd_afm.h  Parsing afm tables to find width of strings.
- ****************************************************************************/
+ ****************************************************************************
+ * $Id: rrd_afm.c 1050 2007-05-02 18:06:05Z oetiker $
+*/
 
 #if defined(_WIN32) && !defined(__CYGWIN__) && !defined(__CYGWIN32__) && !defined(HAVE_CONFIG_H)
-#include "../confignt/config.h"
+#include "../win32/config.h"
 #else
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "../rrd_config.h"
 #endif
 #endif
 
