@@ -10,14 +10,15 @@
 
 #define ALTYGRID  	 0x01	/* use alternative y grid algorithm */
 #define ALTAUTOSCALE	 0x02	/* use alternative algorithm to find lower and upper bounds */
-#define ALTAUTOSCALE_MAX 0x04	/* use alternative algorithm to find upper bounds */
-#define NOLEGEND	 0x08	/* use no legend */
-#define NOMINOR          0x10    /* Turn off minor gridlines */
-#define ONLY_GRAPH       0x20   /* use only graph */
-#define FORCE_RULES_LEGEND 0x40	/* force printing of HRULE and VRULE legend */
+#define ALTAUTOSCALE_MIN 0x04	/* use alternative algorithm to find lower bounds */
+#define ALTAUTOSCALE_MAX 0x08	/* use alternative algorithm to find upper bounds */
+#define NOLEGEND	 0x10	/* use no legend */
+#define NOMINOR          0x20    /* Turn off minor gridlines */
+#define ONLY_GRAPH       0x40   /* use only graph */
+#define FORCE_RULES_LEGEND 0x80	/* force printing of HRULE and VRULE legend */
 
-#define FORCE_UNITS 0x80        /* mask for all FORCE_UNITS_* flags */
-#define FORCE_UNITS_SI 0x80     /* force use of SI units in Y axis (no effect in linear graph, SI instead of E in log graph) */
+#define FORCE_UNITS 0x100        /* mask for all FORCE_UNITS_* flags */
+#define FORCE_UNITS_SI 0x100     /* force use of SI units in Y axis (no effect in linear graph, SI instead of E in log graph) */
 
 enum tmt_en {TMT_SECOND=0,TMT_MINUTE,TMT_HOUR,TMT_DAY,
 	     TMT_WEEK,TMT_MONTH,TMT_YEAR};
@@ -155,14 +156,14 @@ typedef struct image_desc_t {
 #endif
     gfx_color_t    graph_col[__GRC_END__]; /* real colors for the graph */   
     text_prop_t    text_prop[TEXT_PROP_LAST]; /* text properties */
-    char           ylegend[200];   /* legend along the yaxis */
-    char           title[200];     /* title for graph */
-    char           watermark[100];   /* watermark for graph */
+    char           ylegend[210];   /* legend along the yaxis */
+    char           title[210];     /* title for graph */
+    char           watermark[110];   /* watermark for graph */
     int            draw_x_grid;      /* no x-grid at all */
     int            draw_y_grid;      /* no x-grid at all */
     double         grid_dash_on, grid_dash_off;
     xlab_t         xlab_user;      /* user defined labeling for xaxis */
-    char           xlab_form[200]; /* format for the label on the xaxis */
+    char           xlab_form[210]; /* format for the label on the xaxis */
 
     double         ygridstep;      /* user defined step for y grid */
     int            ylabfact;       /* every how many y grid shall a label be written ? */
@@ -191,11 +192,13 @@ typedef struct image_desc_t {
 #endif
     long           ximg,yimg;      /* total size of the image */
     double         magfact;        /* numerical magnitude*/
-    long         base;            /* 1000 or 1024 depending on what we graph */
+    long         base;             /* 1000 or 1024 depending on what we graph */
     char           symbol;         /* magnitude symbol for y-axis */
     float          viewfactor;     /* how should the numbers on the y-axis be scaled for viewing ? */
-    int            unitsexponent;    /* 10*exponent for units on y-asis */
+    int            unitsexponent;  /* 10*exponent for units on y-asis */
     int            unitslength;    /* width of the yaxis labels */
+    int            forceleftspace; /* do not kill the space to the left of the y-axis if there is no grid */
+
     int            extra_flags;    /* flags for boolean options */
     /* data elements */
 
@@ -246,7 +249,6 @@ int rrd_graph(int, char **, char ***, int *, int *, FILE *, double *, double *);
 void rrd_graph_init(image_desc_t *);
 void rrd_graph_options(int, char **, image_desc_t *);
 void rrd_graph_script(int, char **, image_desc_t *, int);
-int rrd_graph_check_vname(image_desc_t *, char *, char *);
 int rrd_graph_color(image_desc_t *, char *, char *, int);
 int bad_format(char *);
 int vdef_parse(struct graph_desc_t *,const char *const);
