@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
+ * RRDtool 1.2.23  Copyright by Tobi Oetiker, 1997-2007
  *****************************************************************************
  * rrd_tool.c  Startup wrapper
  *****************************************************************************/
@@ -29,7 +29,7 @@ void PrintUsage(char *cmd)
     char help_list[] =
 	   "Valid commands: create, update, updatev, graph, dump, restore,\n"
 	   "\t\tlast, lastupdate, first, info, fetch, tune,\n"
-	   " resize, xport\n\n";
+	   "\t\tresize, xport\n\n";
 
     char help_listremote[] =
            "Valid remote commands: quit, ls, cd, mkdir, pwd\n\n";
@@ -689,8 +689,8 @@ int HandleInputLine(int argc, char **argv, FILE* out)
 	char          **legend_v;
         int           enumds = 0;
         int           i;
-        char *vtag = NULL;
-        vtag = malloc( strlen(COL_DATA_TAG)+10);
+        size_t       vtag_s = strlen(COL_DATA_TAG) + 10; 
+        char         *vtag = malloc(vtag_s); 
 	for ( i = 2; i < argc; i++){
 		if (strcmp("--enumds", argv[i]) == 0)
 			enumds = 1;
@@ -724,9 +724,9 @@ int HandleInputLine(int argc, char **argv, FILE* out)
 	    for (j = 0; j < col_cnt; j++) {
 	      rrd_value_t newval = DNAN;
               if (enumds == 1)
-		snprintf(vtag,sizeof(vtag),"%s%lu", COL_DATA_TAG, j);
+		snprintf(vtag,vtag_s,"%s%lu", COL_DATA_TAG, j);
 	      else
-		snprintf(vtag,sizeof(vtag),"%s",COL_DATA_TAG);
+		snprintf(vtag,vtag_s,"%s",COL_DATA_TAG);
               
 	      newval = *ptr;
 	      if(isnan(newval)){
