@@ -1,9 +1,9 @@
 /*****************************************************************************
- * RRDtool 1.2.19  Copyright by Tobi Oetiker, 1997-2007
+ * RRDtool 1.2.23  Copyright by Tobi Oetiker, 1997-2007
  *****************************************************************************
  * change header parameters of an rrd
  *****************************************************************************
- * $Id: rrd_tune.c 986 2007-02-01 05:51:34Z oetiker $
+ * $Id: rrd_tune.c 1050 2007-05-02 18:06:05Z oetiker $
  * $Log$
  * Revision 1.6  2004/05/26 22:11:12  oetiker
  * reduce compiler warnings. Many small fixes. -- Mike Slifcak <slif@bellsouth.net>
@@ -290,7 +290,7 @@ rrd_tune(int argc, char **argv)
 		   rrd.ds_def[i].par[DS_min_val].u_val,
 		   rrd.ds_def[i].par[DS_max_val].u_val);
 		} else {
-		char *buffer;
+		char *buffer = NULL;
 		rpn_compact2str((rpn_cdefds_t *) &(rrd.ds_def[i].par[DS_cdef]),rrd.ds_def,&buffer);
 		printf("DS[%s] typ: %s\tcdef: %s\n", rrd.ds_def[i].ds_nam,rrd.ds_def[i].dst,buffer);
 	    free(buffer);
